@@ -1,6 +1,6 @@
 package Net::WebSocket;
 
-our $VERSION = '0.052-TRIAL2';
+our $VERSION = '0.1-TRIAL2';
 
 =encoding utf-8
 
@@ -29,19 +29,17 @@ Net::WebSocket - WebSocket in Perl
     Net::WebSocket::HTTP_R::handshake_parse_response( $handshake, $resp );
 
     #See below about IO::Framed
-    my $parser = Net::WebSocket::Parser->new(
-        IO::Framed::Read->new($inet),
-    );
+    my $iof = IO::Framed->new($inet);
 
-    my $iof_w = IO::Framed::Write->new($inet);
+    my $parser = Net::WebSocket::Parser->new($iof);
 
     my $ept = Net::WebSocket::Endpoint::Client->new(
         parser => $parser,
-        out => $iof_w,
+        out => $iof,
     );
 
     $iof_w->write(
-        Net::WebSocket::Frame::text->new( payload_sr => \'Hello, world' )
+        Net::WebSocket::Frame::text->new( payload => 'Hello, world' )
     );
 
     #Determine that $inet can be read from …
@@ -79,10 +77,10 @@ Net::WebSocket emphasizes flexibility and lightness rather than the more
 monolithic approach in modules like L<Mojolicious>.
 Net::WebSocket should support anything
 that the WebSocket protocol itself can do, as lightly as possible and without
-prejudice as to how you want to do it: extensions, blocking/non-blocking I/O,
-arbitrary HTTP headers, etc. Net::WebSocket will likely require more of an
-investment up-front, but the end result should be a clean, light
-implementation that will grow (or shrink!) as your needs dictate.
+prejudice as to how you want to do it: extensions, streaming, blocking or
+non-blocking I/O, arbitrary HTTP headers, etc. The end result should be a
+clean, light implementation that will grow (or shrink!) as your needs
+dictate.
 
 =head1 OVERVIEW
 
@@ -216,8 +214,8 @@ L<Net::WebSocket::PMCE::deflate> for more details.
 
 =head1 TODO
 
-At this point Net::WebSocket should support every widely implemented
-WebSocket feature.
+At this point Net::WebSocket seems to support everything the WebSocket
+protocol can (usefully) do, including compression.
 
 =over
 
@@ -227,9 +225,8 @@ WebSocket feature.
 
 =head1 SEE ALSO
 
-L<Mojolicious> is probably CPAN’s easiest WebSocket implementation to get
-a server up and running. If you’re building a project from scratch, you
-may find this to be a better fit for you than Net::WebSocket.
+L<Mojolicious> has a WebSocket implementation. It’s not as complete as
+Net::WebSocket, but if you’re using Mojolicious, you might try this first.
 
 L<Protocol::WebSocket> is an older module that supports
 pre-standard versions of the WebSocket protocol. It’s similar to this one
@@ -239,7 +236,8 @@ things like automatic ping/pong/close, classes for each message type, etc.
 L<Net::WebSocket::Server> implements only server behaviors and
 gives you more automation than P::WS.
 
-L<Net::WebSocket::EV> uses XS to call a C library.
+L<Net::WebSocket::EV> uses XS to call L<wslay|http://wslay.sourceforge.net>.
+As of this writing it lacks support for handshake logic.
 
 =head1 REPOSITORY
 
@@ -251,7 +249,7 @@ Felipe Gasper (FELIPE)
 
 =head1 COPYRIGHT
 
-Copyright 2017 by L<Gasper Software Consulting, LLC|http://gaspersoftware.com>
+Copyright 2017 by L<Gasper Software Consulting|http://gaspersoftware.com>
 
 =head1 LICENSE
 
